taoensso.nippy.io

Private low-level utils for reading/writing data, don't use.

Private low-level utils for reading/writing data, don't use.
raw docstring

bb->dinclj

(bb->din bb)

Returns a DataInput adapter over given ByteBuffer. Reads from the buffer's current position and advances it.

Returns a `DataInput` adapter over given `ByteBuffer`.
Reads from the buffer's current position and advances it.
raw docstring

bb->doutclj

(bb->dout bb)

Returns a DataOutput adapter over given ByteBuffer. Writes at the buffer's current position and advances it.

Returns a `DataOutput` adapter over given `ByteBuffer`.
Writes at the buffer's current position and advances it.
raw docstring

bb-big-endian!clj

(bb-big-endian! bb)

IWriteTypedNoMetacljprotocol

write-typedclj

(write-typed _ bb dout_)

Writes given object as type-prefixed bytes. Excludes IObj meta.

Writes given object as type-prefixed bytes. Excludes IObj meta.

IWriteTypedNoMetaDincljprotocol

write-typed-dinclj

(write-typed-din _ dout)

Writes given object as type-prefixed bytes. Excludes IObj meta. Takes legacy DataInput, used for custom extensions.

Writes given object as type-prefixed bytes. Excludes IObj meta. Takes legacy `DataInput`, used for custom extensions.

IWriteTypedWithMetacljprotocol

write-typed+metaclj

(write-typed+meta _ bb dout_)

Writes given object as type-prefixed bytes. Includes IObj meta when present.

Writes given object as type-prefixed bytes. Includes IObj meta when present.

read-bigintegerclj

(read-biginteger ibr)

read-bytesclj

(read-bytes ibr)
(read-bytes ibr len)

read-bytes-lgclj

(read-bytes-lg ibr)

read-bytes-mdclj

(read-bytes-md ibr)

read-bytes-smclj

(read-bytes-sm ibr)

read-bytes-sm*clj

(read-bytes-sm* ibr)

read-customclj

(read-custom ibr prefixed? type-id)

read-intoclj

(read-into to ibr n)

read-kvs-deprclj

(read-kvs-depr to ibr)

read-kvs-intoclj

(read-kvs-into to ibr n)

read-lg-countcljmacro

(read-lg-count ibr)

read-md-countcljmacro

(read-md-count ibr)

read-quarantined-serializable-object-unsafe!clj

(read-quarantined-serializable-object-unsafe! m)

Given a quarantined Serializable object like {:nippy/unthawable {:class-name <> :content <quarantined-ba>}}, reads and returns the object WITHOUT regard for *thaw-serializable-allowlist*.

MAY BE UNSAFE! Don't call this unless you absolutely trust the payload to not contain any malicious code.

See *thaw-serializable-allowlist* for more info.

Given a quarantined Serializable object like
{:nippy/unthawable {:class-name <> :content <quarantined-ba>}}, reads and
returns the object WITHOUT regard for `*thaw-serializable-allowlist*`.

**MAY BE UNSAFE!** Don't call this unless you absolutely trust the payload
to not contain any malicious code.

See `*thaw-serializable-allowlist*` for more info.
raw docstring

read-recordclj

(read-record ibr class-name)

read-sm-countcljmacro

(read-sm-count ibr)

read-sm-ucountcljmacro

(read-sm-ucount ibr)

read-strclj

(read-str ibr)
(read-str ibr len)

read-str-lgclj

(read-str-lg ibr)

read-str-mdclj

(read-str-md ibr)

read-str-smclj

(read-str-sm ibr)

read-str-sm*clj

(read-str-sm* ibr)

read-szclj

(read-sz ibr class-name legacy?)

read-sz!!clj

(read-sz!! input-stream class-name)

Reads object using Java Serializable. May be unsafe!

Reads object using Java `Serializable`. May be unsafe!
raw docstring

read-typeclj

(read-type ibr class-name)

read-typedclj

(read-typed ibr)

Reads one object as type-prefixed bytes from given IByteReader.

Reads one object as type-prefixed bytes from given `IByteReader`.
raw docstring

with-bbclj

(with-bb f)
(with-bb init-size f)
(with-bb bb cache_ cache f)

Executes (f bb dout_) and returns ?ba of bb when f returns truthy. bb ---- Auto-expanding ByteBuffer. Will reuse ThreadLocal when possible, currently only freed via GC when thread dies. dout_ - Call (dout_) to get a DataOutput view on bb.

Executes `(f bb dout_)` and returns ?ba of bb when `f` returns truthy.
`bb` ---- Auto-expanding `ByteBuffer`. Will reuse ThreadLocal when possible,
          currently only freed via GC when thread dies.
`dout_` - Call (dout_) to get a `DataOutput` view on `bb`.
raw docstring

write-bigintegerclj

(write-biginteger bb n)

write-bytesclj

(write-bytes bb ba)

write-bytes-lgclj

(write-bytes-lg bb ba)

write-bytes-mdclj

(write-bytes-md bb ba)

write-bytes-smclj

(write-bytes-sm bb ba)

write-bytes-sm*clj

(write-bytes-sm* bb ba)

write-cachedclj

(write-cached bb dout_ x-val cache_)

write-collclj

(write-coll bb dout_ id-lg coll)
(write-coll bb dout_ id-empty id-sm id-md id-lg coll)

write-counted-collclj

(write-counted-coll bb dout_ id-lg coll)
(write-counted-coll bb dout_ id-empty id-sm id-md id-lg coll)

write-dyn-array-lgcljmacro

(write-dyn-array-lg bb dout_ arr alen id)

Writes an array of dynamic (individually type-prefixed) elements.

Writes an array of dynamic (individually type-prefixed) elements.
raw docstring

write-idcljmacro

(write-id bb id)

write-kvsclj

(write-kvs bb dout_ id-lg coll)
(write-kvs bb dout_ id-empty id-sm id-md id-lg coll)

write-kwclj

(write-kw bb kw)

write-lg-countcljmacro

(write-lg-count bb n)

write-longclj

(write-long bb n)

write-long-legacyclj

(write-long-legacy bb n)

write-mapclj

(write-map bb dout_ m is-metadata?)

Micro-optimized write-kvs w/ id-map-0 id-map-sm id-map-md id-map-lg.

Micro-optimized `write-kvs` w/ id-map-0 id-map-sm id-map-md id-map-lg.
raw docstring

write-md-countcljmacro

(write-md-count bb n)

write-readableclj

(write-readable bb x)

write-setclj

(write-set bb dout_ s)

Micro-optimized write-counted-coll w/ id-set-0 id-set-sm id-set-md id-set-lg.

Micro-optimized `write-counted-coll` w/ id-set-0 id-set-sm id-set-md id-set-lg.
raw docstring

write-sm-countcljmacro

(write-sm-count bb n)

write-sm-ucountcljmacro

(write-sm-ucount bb n)

write-strclj

(write-str bb s)

write-str-lgclj

(write-str-lg bb s)

write-str-mdclj

(write-str-md bb s)

write-str-smclj

(write-str-sm bb s)

write-str-sm*clj

(write-str-sm* bb s)

write-symclj

(write-sym bb s)

write-szclj

(write-sz bb x)

Writes given arg using Java Serializable. Returns true iff allowed.

Writes given arg using Java `Serializable`.
Returns true iff allowed.
raw docstring

write-uncounted-collclj

(write-uncounted-coll bb dout_ id-lg coll)
(write-uncounted-coll bb dout_ id-empty id-sm id-md id-lg coll)

write-vecclj

(write-vec bb dout_ v)

cljdoc builds & hosts documentation for Clojure/Script libraries